#!/bin/sh
BUILD_INTERP=hpux10
 #
 # Component Name: TEC Adapters
 #
 # (C) COPYRIGHT TIVOLI Systems 1998
 # Unpublished Work
 # All Rights Reserved
 # Licensed Material - Property of TIVOLI Systems
 #
 #------------------------------------------------------------------------------

 #------------------------------------------------------------------------------
 # adapter_fns.sh includes install_fns.sh
 #------------------------------------------------------------------------------



 #-------------------------------------------------------------------
 # Special note for this file (adapter_fns.sh):
 #
 # This file is a library of shell script functions.  It is #include'ed in
 # other shell script files.  The 'make' rules run the C pre-processor on
 # the shell script so that these functions are imbedded within the main
 # script.  Because shell script comments and C pre-processor directives
 # both begin with the hash character (#), edit with care.  cpp directives
 # must begin in column 1, so just keep all shell script comments indented
 # at least 1 space and you'll be okay.
 #-------------------------------------------------------------------






















	TIV_ENV=
	LCF_ENV=FALSE

	print_out()
	{
		echo $1
	}

	print_err()
	{
		echo $1 >&2
	}



 ##-------------------------------------------------------------------
 ## Special note for this file (install_fns.sh):
 ##
 ## This file is a library of shell script functions.  It is #include'ed in
 ## other shell script files.  The 'make' rules run the C pre-processor on
 ## the shell script so that these functions are imbedded within the main
 ## script.  Because shell script comments and C pre-processor directives
 ## both begin with the hash character (#), edit with care.
 ##
 ## On some OS's, cpp directives must begin in column 1, so just keep all
 ## shell script comments indented at least 1 space and you'll be okay.
 ##
 ## However, on other OS's (e.g., Windows, AIX 4), cpp directives are parsed
 ## even if the '#' is not in column 1, so I use '##' for comments.
 ##-------------------------------------------------------------------
























	LCF_ENV=FALSE
print_out()
{
	echo $1
}

print_err()
{
	echo $1 >&2
}



 ## Just some initial defaults.  TMPDIR is expected to be set by get_temp_dir,
 ## but we give it a default value of the current directory, in case it is
 ## used before calling get_temp_dir.
 ##
TEC_TEMP_FILE=tec_temp
TMPDIR=${_TMP:-.}
RM="rm -f"

DEBUG_LVL=0

	## A function for getting the installation locations for the various
	## packages (MAN, LIB ... etc)
	## $1 must be the managed node name
	## $2 must be the package name
get_locations()
{
	set +e
	HOST=$1
	PACKAGE=$2

	IOID=`wlookup Installation`
	LOCATIONS=`idlcall $IOID get_host_locations "{ 1 \"$HOST\" }"`
	count=2
	elements=`echo $LOCATIONS | idlarg 1`
	elements=`expr $elements + 1`

	while [ $count -ne $elements ]; do
		DESC=`echo $LOCATIONS | idlarg $count`
		PACK=`echo $DESC | grep \"$PACKAGE\"`
		DIR=`echo $PACK | cut -d ' ' -f3`
		DIR=`echo $DIR | cut -d '"' -f2`
		OTHER=`echo $PACK | cut -d ' ' -f4`

		if [ ! -z "$DIR" ]; then
			case $PACKAGE in
				MAN | LIB | ALIDB | DB | BIN )
					if [ $INTERP = "w32-ix86" ]; then
						echo $DIR/$OTHER | sed -e 's/\\/\//g'
					else
						echo $DIR/$OTHER
					fi;;
				CAT )
					if [ $INTERP = "w32-ix86" ]; then
						echo $DIR | sed -e 's/\\/\//g'
					else
						echo $DIR
					fi;;
			esac
			break
		fi

		count=`expr $count + 1`
	done
}

get_temp_dir()
{
	if [ $# -gt 0 ]; then
		READ_ENV=$1
	else
		READ_ENV=TRUE
	fi

	if [ -z "$EXECDIR" -o -z "$INTERP" ]; then
		get_tme_env
	fi

	##-------------------------------------------------------------------
	## Use wtemp to find temporary directory, if possible
	##-------------------------------------------------------------------
	if [ -x $EXECDIR/$INTERP/bin/wtemp$EXE ]; then
		TMPDIR=`$EXECDIR/$INTERP/bin/wtemp$EXE` || :
	else
		if [ -n "$EXECDIR" ]; then
			TMPDIR=`wtemp$EXE` || :
		fi
	fi

	TMPDIR=${TMPDIR:-$TEMP}
	TMPDIR=${TMPDIR:-/tmp}

	if [ "$READ_ENV" = "TRUE" -a -f $TMPDIR/TransferEnv ]; then
		if [ -z "$TEST_EXEC_FLAG" ]; then
			get_interp_env
		fi

		. $TMPDIR/TransferEnv
		$RM $TMPDIR/TransferEnv
	fi
}

set_TME_ENV()
{

	set +e
	if [ -z "$TME_ENV" ]; then
		TME_ENV=FALSE
		TIV_ENV=NONTME
	else
		TIV_ENV=TME
	fi
	set -e




}

get_interp()
{
	set_TME_ENV

	if [ "$TME_ENV" = "TRUE" ]; then
		BO=${BO:-`objcall 0.0.0 self`}
		OSERV=${OSERV:-`objcall $BO getattr oserv`}
		INTERP=${INTERP:-`objcall $OSERV query interp`}
	else
		##-------------------------------------------------------------
		## Guess the interpreter type if not set
		##     (this came from as/Install/wserver.sh)
		##-------------------------------------------------------------
		if [ -z "$INTERP" ]; then
			if [ -n "$BUILD_INTERP" ]; then
				INTERP=$BUILD_INTERP
			else
				UN_MACHINE=`(uname -m) 2>/dev/null` || UN_MACHINE=unknown
				UN_RELEASE=`(uname -r) 2>/dev/null` || UN_RELEASE=unknown
				UN_SYSTEM=`(uname -s) 2>/dev/null` || UN_SYSTEM=unknown
				UN_VERSION=`(uname -v) 2>/dev/null` || UN_VERSION=unknown

				case "${UN_MACHINE}:${UN_SYSTEM}:${UN_RELEASE}:${UN_VERSION}" in
					Pentium*:Windows_NT:*:*)
						INTERP="w32-ix86";;

					AViiON:dgux:5.*:*)
						INTERP="dgux5";;

					*:SunOS:4.*:*)
						INTERP="sunos4";;

					*:CSROS:*)
						INTERP="sunos4";;

					*:SunOS:5.*:*)
						INTERP="solaris2";;

					*:AIX:2:3)
						INTERP="aix3-r2";;

					*:AIX:*:4)
						INTERP="aix4-r1";;

					*:HP-UX:*.09.*:*)
						INTERP="hpux9";;

					*:HP-UX:*.10.*:*)
						INTERP="hpux10";;

					m88k:*:4*:R4*)
						INTERP="sysv4-m88k";;

					*:*:4.0:3.0)
						INTERP="sysv4-att";;
				esac

				if [ -z "$INTERP" ]; then
					print_err 'Unable to guess system type.  Try setting $INTERP.'
					exit	1
				fi
			fi
		else
			 print_out "Using the interpreter type $INTERP as set in your environment."
		fi
	fi
}

get_tme_env()
{
	set_TME_ENV

	if [ "$TME_ENV" = "TRUE" -o "$LCF_ENV" = "TRUE" ]; then

		if [ -z "$INTERP" ]; then
			get_interp
		fi










		BO=${BO:-`objcall 0.0.0 self`}
		OSERV=${OSERV:-`objcall $BO getattr oserv`}
		EXECDIR=${EXECDIR:-`objcall $OSERV query install_dir`}
		DBDIR=${DBDIR:-`objcall $OSERV query db_dir`}
		LCF_WORK_DIR=

		##-------------------------------------------------------------
		## The backslash causes problems when passed to idlcall
		##-------------------------------------------------------------
		if [ "$INTERP" = "w32-ix86" ]; then
			EXECDIR=`echo $EXECDIR | sed -e "s,\\\\\,/,g"`
			DBDIR=`echo $DBDIR | sed -e "s,\\\\\,/,g"`
		fi

		TECADHOME=${TECADHOME:-$EXECDIR/$INTERP/TME/TEC/adapters}
		ADAPTER_CFG_DIR=$TECADHOME/bin


		HOID=`objcall 0.0.0 get_host_location`
		HOST=`idlattr -tg $HOID label string | cut -d '"' -f2`
		BINDIR=${BINDIR:-`get_locations $HOST BIN`}
		LIBDIR=${LIBDIR:-`get_locations $HOST LIB`}
		MANDIR=${MANDIR:-`get_locations $HOST MAN`}
		MSGDIR=${MSGDIR:-`get_locations $HOST CAT`}

		##-------------------------------------------------------------
		## The backslash causes problems everywhere
		##-------------------------------------------------------------
		if [ "$INTERP" = "w32-ix86" ]; then
			BINDIR=`echo $BINDIR | sed -e "s,\\\\\,/,g"`
			LIBDIR=`echo $LIBDIR | sed -e "s,\\\\\,/,g"`
			MANDIR=`echo $MANDIR | sed -e "s,\\\\\,/,g"`
			MSGDIR=`echo $MSGDIR | sed -e "s,\\\\\,/,g"`
		fi

	fi
}

 ##-------------------------------------------------------------------
 ## Setup certain interp-specific variables
 ##-------------------------------------------------------------------
get_interp_env() {
	if [ -z "$INTERP" ]; then
		get_interp
	fi

	if [ "$INTERP" = "w32-ix86" ]; then
		CPOPTS=""
		EXE=.exe
		RM="rm -f"
		TEST_EXEC_FLAG="-f"

		if [ "$LCF_ENV" != "TRUE" ]; then
			TASK_DIR=`echo $SystemRoot/system32/drivers | sed -e "s,\\\\\,/,g"`
		fi
	else
		CPOPTS="-p"
		EXE=
		RM="/bin/rm -f"
		TASK_DIR=
		TEST_EXEC_FLAG="-x"
	fi
}



 ##-----------------------------------------------------------------------------
 ## A function to check for a class installation, to allow re-install if
 ## appropriate, and to install the class if it has not yet been installed.
 ##-----------------------------------------------------------------------------
install_class()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	_class_name=$1
	_oname=$2
	_cfg_file=$3

	set +e
	CLO=${CLO:-`wlookup Library`}
	_class_obj=`objcall $CLO _lookup_object $_class_name`
	rc=$?
	set -e

	if [ $rc -eq 0 ] ; then
		_obj_tmr_num=`echo $_class_obj | cut -d. -f1`
		_mn_obj=`objcall 0.0.0 get_host_location`
		_mn_tmr_num=`echo $_mn_obj | cut -d. -f1`

		if [ "$_obj_tmr_num" = "$_mn_tmr_num" ]; then
			set +x
			echo ""
			echo "-- Note: The $APPNAME class $_class_name has"
			echo "-- already been created and installed in this TMR."
			echo "-- It is assumed that you are attempting to re-install this"
			echo "-- product."
			echo ""
			set -x
		else
			run_cfg_file $_oname $_cfg_file
		fi
	else
		run_cfg_file $_oname $_cfg_file
	fi
}

remove_class()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	_class_name=$1
	CLO=${CLO:-`wlookup Library`}
	TNR=`wlookup NameRegistry`

	##----------------------------------------------------------------
	## Get the class object ID
	##----------------------------------------------------------------
	CO=`idlcall -v $CLO TMF_SysAdmin::Library::lookup_object \"$_class_name\" {0}`
	rc=$?

	if [ $rc -ne 0 ] ; then
		return
	fi

	if [ $? -eq 0 ]; then
		echo "Removing class $_class_name..."

		##-------------------------------------------------------------
		## Delete all the instances of the class
		##-------------------------------------------------------------
		members=`objcall $CO _get_members`

		if [ $? -eq 0 -a -n "$members" ]; then
			for i in $members; do
				echo "   Removing $i..."
				idlcall -T top -v $i remove
			done
		fi

		##-------------------------------------------------------------
		## Remove the extension object
		##-------------------------------------------------------------
		EXTENSION=`idlattr -t -g $CO extension Object`

		if [ $? -eq 0 -a -n "$EXTENSION" -a "$EXTENSION" != "$CO" ]; then
			objcall $EXTENSION rmobj
		fi

		##-------------------------------------------------------------
		## Remove the prototype objects
		##-------------------------------------------------------------
		PROTO_SEQ=`idlattr -t -g $CO prototypes SysAdminTypes::ObjectList`

		if [ $? -eq 0 -a -n "$PROTO_SEQ" ]; then
			PROTO_LIST=`echo $PROTO_SEQ | sed 's,{ *[0-9]* *\(.*\) *},\1,'`

			for PROTO in $PROTO_LIST ; do
				objcall $PROTO rmobj
			done
		fi

		##-------------------------------------------------------------
		## Remove the behavior object
		##-------------------------------------------------------------
		BEHAVE=`idlattr -t -g $CO behavior Object`

		if [ $? -eq 0 -a -n "$BEHAVE" -a "$BEHAVE" != "$CO" ]; then
			objcall $BEHAVE rmobj
		fi

		if [ "$_class_name" = "ACPEP" ]; then
			MNCO=`idlcall $CLO TMF_SysAdmin::Library::lookup_object '"ManagedNode" {0}'`
			MNBO=`idlattr -tg $MNCO behavior Object`
			objcall $MNBO oi_remove $BEHAVE

			EPCO=`wlookup -orClasses Endpoint`
			EPBO=`idlattr -tg $EPCO behavior Object`
			objcall $EPBO oi_remove $BEHAVE
		fi

		##-------------------------------------------------------------
		## Remove the class object
		##-------------------------------------------------------------
		idlcall -T top -v $CO TMF_SysAdmin::InstanceManager::remove

		##----------------------------------------------------------
		## Clean out the name registry.
		##----------------------------------------------------------
		ISREG=`wlookup -r Classes $_class_name > /dev/null 2>&1 `

		if [ $? -eq 0 ]; then
			wregister -u -r Classes $_class_name
		elif wlookup -r distinguished $_class_name 2> /dev/null; then
			wregister -u $_class_name
		fi

		idlcall -v $TNR TMF_TNR::Resource::remove \"$_class_name\" TRUE > /dev/null
	else
		echo "Class $_class_name not found"
	fi
}

remove_ProductInfo()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	## Remove the product and patch installation objects

	echo "Removing Product and Patch objects for $1"
	PROD_IO=`wlookup -r ProductInfo $1 2>/dev/null`

	if [ $? -eq 0 -a -n "$PROD_IO" ];then
		PATCH_SEQ=`idlcall -v $PROD_IO _get_patches`
		PATCH_LIST=`echo $PATCH_SEQ | sed 's,{ *[0-9]* *\(.*\) *},\1,'`

		for PATCH in $PATCH_LIST ; do
			idlcall -v $PATCH TMF_SysAdmin::PolicyDrivenBase::remove
		done

		idlcall -v $PROD_IO TMF_SysAdmin::PolicyDrivenBase::remove
	fi
}

remove_presentation()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	PRES=`wlookup -r Presentation $1`
	[ -n "$PRES" ] && idlcall -v $PRES TMF_SysAdmin::PolicyDrivenBase::remove
}

 ##-----------------------------------------------------------------------------
 ## Work-around to remove Notice groups. The direct remove does not always work
 ##-----------------------------------------------------------------------------
remove_NoticeGroup()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	echo "Removing Notice Groups..."
	NOTICEGROUP="$1"
	CLO=${CLO:-`wlookup Library`}
	CO=`idlcall -v $CLO TMF_SysAdmin::Library::lookup_object \"TMF_Notice\" {0}`

	if [ $? -eq 0 -a -n "$CO" ]; then
		members=`objcall $CO _get_members`

		if [ $? -eq 0 -a -n "$members" ]; then
			for i in $members; do
				LABEL=`idlattr -tg $i label string`
				LABEL=`eval echo "$LABEL"`

				if [ "$LABEL" = "$NOTICEGROUP" ];then
					echo "     removing Notice Group $LABEL"
					idlcall -v -T top $CO remove_object TRUE $i
					wregister -r TMF_Notice -u "$LABEL"
					objcall $i rmobj
				fi
			done
		fi
	fi
}

 ##-----------------------------------------------------------------------------
 ## The first argument is the name of the role list
 ##     (supported_roles | supported_tmr_roles)
 ##
 ## The remaining arguments are the roles to remove
 ##-----------------------------------------------------------------------------
fix_role_list()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	ROLE_LIST=$1
	shift
	echo "Updating $ROLE_LIST"

	##---------------------------------------------------------------------------
	## Get the Administrator object to update and the current roles
	##---------------------------------------------------------------------------
	_ROLE_ADMIN=${_ROLE_ADMIN:-`wlookup Administrators`}
	ROLES=`idlcall $_ROLE_ADMIN _get_$ROLE_LIST`
	OLD_COUNT=`echo $ROLES | cut -f 2 -d " "`
	NEW_COUNT=$OLD_COUNT

	SED_CMD=""

	##---------------------------------------------------------------------------
	## For each role to remove, if it is in the current list then add a
	## substitution command to the 'sed' statement and decrement the count of
	## roles.
	##---------------------------------------------------------------------------
	for RM_ROLE in $*; do
		if echo $ROLES | egrep "\"$RM_ROLE\"" ; then
			if [ -z "$SED_CMD" ]; then
				SED_CMD="s/\"${RM_ROLE}\"//g"
			else
				SED_CMD="${SED_CMD};s/\"${RM_ROLE}\"//g"
			fi

			NEW_COUNT=`expr $NEW_COUNT - 1`
		fi
	done

	##---------------------------------------------------------------------------
	## If at least one role needs to be removed, add a substitution command to
	## the 'sed' statement to change the sequence length then update the
	## attribute.
	##---------------------------------------------------------------------------
	if [ "$OLD_COUNT" != "$NEW_COUNT" ]; then
		SED_CMD="${SED_CMD};s/$OLD_COUNT/$NEW_COUNT/"
		NEW_ROLES=`echo $ROLES | sed "$SED_CMD"`
		idlcall $_ROLE_ADMIN _set_$ROLE_LIST $NEW_ROLES
	fi
}

remove_roles()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	echo "Updating Roles"

	fix_role_list supported_roles     $*
	fix_role_list supported_tmr_roles $*
}

update_managed_resources()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	RESOURCE="$1"
	echo "Updating managed resources..."

	for x in `wls -l /Library/PolicyRegion | awk '{print $1}'`; do
		LABEL=`idlattr -tg $x label Object`
		HASIT=`wgetpr "@$LABEL" | grep "$RESOURCE"`

		if [ -n "$HASIT" ];then
			wsetpr -r $HASIT "@$LABEL"
		fi
	done
}

 ##---------------------------------------------------------------------------
 ## Removes the node from the ProductInfo and PatchInfo objects
 ## related to the application.
 ##---------------------------------------------------------------------------
update_ProductInfo()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	PROD="$1"
	NODE="$2"

	echo "Updating Product and Patch objects..."

	PROD_IO=`wlookup -r ProductInfo "$PROD"`

	if [ $? -eq 0 -a -n "$PROD_IO" ];then
		PATCH_SEQ=`idlcall -v $PROD_IO _get_patches`
		PATCH_LIST=`echo $PATCH_SEQ | sed 's,{ *[0-9]* *\(.*\) *},\1,'`

		for PATCH in $PATCH_LIST ; do
			idlcall -v $PATCH remove_host_locations '{ 1' $NODE '}'
		done

		idlcall -v $PROD_IO remove_host_locations '{ 1' $NODE '}'
	fi
}

remove_cli_files()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	_bin_dir=$1
	_man_dir=$2

	cd $_bin_dir

	##---------------------------------------------------------------------------
	## Remove the binaries
	##---------------------------------------------------------------------------
	xargs rm -f <<EOF
		bin/tec_cl_install
		bin/tec_cl_remove
		bin/waddegflt${EXE}
		bin/wassigneg${EXE}
		bin/wchkclass${EXE}
		bin/wcomprules${EXE}
		bin/wcpeg${EXE}
		bin/wcprb${EXE}
		bin/wcrtconsole${EXE}
		bin/wcrteg${EXE}
		bin/wcrtrb${EXE}
		bin/wcrtsrc${EXE}
		bin/wdeleg${EXE}
		bin/wdelegflt${EXE}
		bin/wdelrb${EXE}
		bin/wdelrbclass${EXE}
		bin/wdelrbrules${EXE}
		bin/wdelsrc${EXE}
		bin/wimprbclass${EXE}
		bin/wimprbrules${EXE}
		bin/wloadrb${EXE}
		bin/wlsassigneg${EXE}
		bin/wlscurrb${EXE}
		bin/wlseg${EXE}
		bin/wlsemsg${EXE}
		bin/wlsesvrcfg${EXE}
		bin/wlsrb${EXE}
		bin/wlsrbclass${EXE}
		bin/wlsrbrules${EXE}
		bin/wlssrc${EXE}
		bin/wsendresp${EXE}
		bin/wseteg${EXE}
		bin/wsetegflt${EXE}
		bin/wsetemsg${EXE}
		bin/wsetesvrcfg${EXE}
		bin/wsetrb${EXE}
		bin/wsetsrc${EXE}
		bin/wstartesvr${EXE}
		bin/wstatesvr${EXE}
		bin/wstopesvr${EXE}
		bin/wtdbclear${EXE}
		bin/wtdbstat${EXE}
		bin/wtdbspace
		bin/wtdumpcr${EXE}
		bin/wtdumper${EXE}
		bin/wtdumprl${EXE}
		bin/wtdumptr${EXE}
		bin/wunassigneg${EXE}
		bin/wrimsql${EXE}
		TME/TEC/tec_agent_demo${EXE}
		TME/TEC/.tec_diag_config
		TME/TEC/contrib/ParseEvents.pl
		TME/TEC/contrib/SendEvents.pl
		TME/TEC/contrib/whotec.pl
		TME/TEC/contrib/events.txt
		TME/TEC/contrib/get_host_by_addr.pl
		TME/TEC/contrib/get_host_by_name.pl
EOF

	##---------------------------------------------------------------------------
	## Remove the man pages
	##---------------------------------------------------------------------------
	cd $_man_dir

	xargs rm -f <<EOF
		man1/waddegflt.1
		man1/wassigneg.1
		man1/wchkclass.1
		man1/wcomprules.1
		man1/wcpeg.1
		man1/wcprb.1
		man1/wcrtconsole.1
		man1/wcrteg.1
		man1/wcrtrb.1
		man1/wcrtsrc.1
		man1/wdeleg.1
		man1/wdelegflt.1
		man1/wdelrb.1
		man1/wdelrbclass.1
		man1/wdelrbrules.1
		man1/wdelsrc.1
		man1/wimprbclass.1
		man1/wimprbrules.1
		man1/wloadrb.1
		man1/wlsassigneg.1
		man1/wlscurrb.1
		man1/wlseg.1
		man1/wlsemsg.1
		man1/wlsesvrcfg.1
		man1/wlsrb.1
		man1/wlsrbclass.1
		man1/wlsrbrules.1
		man1/wlssrc.1
		man1/wsendresp.1
		man1/wseteg.1
		man1/wsetegflt.1
		man1/wsetemsg.1
		man1/wsetesvrcfg.1
		man1/wsetrb.1
		man1/wsetsrc.1
		man1/wstartesvr.1
		man1/wstatesvr.1
		man1/wstopesvr.1
		man1/wtdbclear.1
		man1/wtdbspace.1
		man1/wtdbstat.1
		man1/wtdumpcr.1
		man1/wtdumper.1
		man1/wtdumprl.1
		man1/wtdumptr.1
		man1/wunassigneg.1
EOF
}

 ##-------------------------------------------------------------------
 ## Get the TMR OID or name for inter-region connections
 ##-------------------------------------------------------------------
get_tmr_region_oid()
{
	wlookup InterRegion
}

get_tmr_region_name()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	_IRO=`get_tmr_region_oid`
	_IROname=`idlattr -t -g $_IRO name string`
	eval echo $_IROname
}

 ##-------------------------------------------------------------------
 ## Remove a Policy Region
 ##-------------------------------------------------------------------
remove_policy_region()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	REGION=$1
	IROname=`get_tmr_region_name`

	set +e
	OLDPR=`wlookup -r PolicyRegion "${REGION}#${IROname}"`
	rc=$?

	if [ $rc -eq 0 ] ; then
		wdelpr @${REGION}#${IROname}

		ALI=`objcall 0.0.0 getattr security_objid`
		set `objcall $ALI get_identity`
		ADMIN=$1
		AO="$2"

		if [ -n "$AO" ]; then
			idlcall -v $AO SysAdmin::Collection::remove_object TRUE "$OLDPR"
		else
			echo "Administrator $ADMIN not found.  The current administrators are:"
			wls Administrators
		fi
	fi

	set +x
}

 ##-------------------------------------------------------------------
 ## Create a task library profile manager
 ##-------------------------------------------------------------------
install_policy_region()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	REGION=$1
	IROname=`get_tmr_region_name`

	set +e
	wlookup -r PolicyRegion "${REGION}#${IROname}"
	rc=$?
	set -e

	if [ $rc -ne 0 ] ; then
		wcrtpr -m ProfileManager -m TaskLibrary ${REGION}
		ALI=`objcall 0.0.0 getattr security_objid`
		set `objcall $ALI get_identity`
		ADMIN=$1
		AO="$2"

		if [ -n "$AO" ]; then
			NEWPR=`wlookup -r PolicyRegion ${REGION}#${IROname}`
			idlcall -v $AO SysAdmin::Collection::add_object "$NEWPR"
		else
			echo "Administrator $ADMIN not found.  The current administrators are:"
			wls Administrators
		fi
	fi

	set +x
}

 ##-------------------------------------------------------------------
 ## Update T/EC Tasks task library
 ##-------------------------------------------------------------------
update_task_library()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	REGION=$1
	IROname=`get_tmr_region_name`

	if [ ! -x $EXECDIR/$INTERP/bin/wtll$EXE ]; then
		set +x
		echo "" >&2
		echo "--------- cause of failure ---------" >&2
		echo "-- $EXECDIR/$INTERP/bin/wtll$EXE is not executable." >&2
		E_CODE=40
	else
		set +e

		TASK_LIB=$TASK_DIR/etc/Tivoli/tll.conf/task

		if [ ! -f $TASK_LIB ] ; then
		   set +x
			echo "Unable to update the T/EC Task library." >&2
			echo "$TASK_LIB is not present." >&2
			echo "Please replace this file and re-install this patch" >&2
			exit 1
		fi

		INTERNAL=`grep '?Internal' $TASK_LIB`

		##-------------------------------------------------------------
		## Insure that the new Internal Attribute is there
		##-------------------------------------------------------------
		if [ "$INTERNAL" = "" ]; then
			echo "?Internal" >> $TASK_LIB
		fi

		if [ -x $EXECDIR/$INTERP/tools/cat$EXE ]; then
			CAT=$EXECDIR/$INTERP/tools/cat$EXE
		elif [ -x /bin/cat$EXE ]; then
			CAT=/bin/cat$EXE
		else
			CAT=cat$EXE
		fi

		##-------------------------------------------------------------
		## Save previous task library
		##-------------------------------------------------------------
		## TLIB=`wlookup -r TaskLibrary "T/EC Tasks#${IROname}"`

		## if [ -n "$TLIB" ]; then
		## 	idlcall -v $TLIB _set_label "Old T/EC Tasks"
		## fi

		##-------------------------------------------------------------
		## Replace "T/EC Tasks" library
		##-------------------------------------------------------------
		$EXECDIR/$INTERP/bin/wtll$EXE -r -p "${REGION}#${IROname}" -P $CAT $EXECDIR/$INTERP/TME/TEC/tec_tasks.tll

		if [ $? -ne 0 ] ; then
			set +x
			echo "" >&2
			echo "--------- cause of failure ---------" >&2
			echo "-- $EXECDIR/$INTERP/wtll$EXE failed." >&2
			E_CODE=45
		fi
	fi

	set +x
}

 ##-------------------------------------------------------------------
 ## Run a TIDLC configuration script
 ##-------------------------------------------------------------------
run_cfg_file()
{
	if [ "$DEBUG_LVL" -gt 0 ]; then
		set -x
	fi

	ONAME=$1
	CFG_FILE=$2

	[ -z "$EXECDIR" ] && get_tme_env
	[ -z "$TEST_EXEC_FLAG" -o -z "$INTERP" ] && get_interp_env

	##----------------------------------------------------------------
	## Check whether script exists and is executable
	##----------------------------------------------------------------
	if [ $TEST_EXEC_FLAG $ThisDir/TME/$ONAME/$CFG_FILE ]; then
		CFG_PATH=$ThisDir/TME/$ONAME/$CFG_FILE
		$CFG_PATH $ONAME $ThisDir "." TME
	elif [ $TEST_EXEC_FLAG $EXECDIR/$INTERP/TME/$ONAME/$CFG_FILE ]; then
		CFG_PATH=$EXECDIR/$INTERP/TME/$ONAME/$CFG_FILE
		$CFG_PATH $ONAME $EXECDIR $INTERP TME
	else
		set +x
		echo "" >&2
		echo "--------- cause of failure ---------" >&2
		echo "-- Neither $ThisDir/TME/$ONAME/$CFG_FILE" >&2
		echo "-- or $EXECDIR/$INTERP/TME/$ONAME/$CFG_FILE are executable." >&2
		exit 1
	fi

	if [ $? -ne 0 ] ; then
		 set +x
		 echo "" >&2
		 echo "--------- cause of failure ---------" >&2
		 echo "-- $CFG_PATH failed." >&2
		 exit 1
	fi

	set +x
}

 #-------------------------------------------------------------------
 # Sets $CRCF to the rc file name(s) appropriate for the interp.
 # Sets $MRCD to the directory containing the master rc file for
 # interps which have the rc file linked to different rc directories
 # for different run states.
 #-------------------------------------------------------------------
set_rc_filenames()
{
   case "$INTERP" in
      hpux9)
         CRCF="/etc/rc"
         MRCD=""
         ;;

      sunos4)
         CRCF="/etc/rc.local"
         MRCD=""
         ;;

      aix3-r2|aix4-r1)
         CRCF="/etc/rc.nfs"
         MRCD=""
         ;;

      hpux10)
         CRCF="/sbin/rc3.d/S99${PROD} /sbin/rc0.d/K50${PROD} \
               /sbin/rc1.d/K50${PROD} /sbin/rc2.d/K50${PROD}"
         MRCD="/sbin/init.d"
         ;;

      dgux5)
         CRCF="/etc/rc3.d/S99.${PROD} /etc/rc0.d/K50.${PROD} \
               /etc/rc1.d/K50.${PROD} /etc/rc2.d/K50.${PROD}"

         if [ -d /etc/init.d ]; then
            MRCD="/etc/init.d"
         else
            MRCD="/usr/sbin/init.d"
         fi
         ;;

      w32-ix86)
         CRCF=""
         MRCD=""
         ;;

      *)
         CRCF="/etc/rc3.d/S99${PROD} /etc/rc0.d/K50${PROD} \
               /etc/rc1.d/K50${PROD} /etc/rc2.d/K50${PROD}"

         if [ -d /etc/init.d ]; then
            MRCD="/etc/init.d"
         else
            MRCD="/usr/sbin/init.d"
         fi
         ;;
   esac
}

 #------------------------------------------------------------------
 # Set up TEC adapter removal script
 #------------------------------------------------------------------
configure_removal_script()
{
	TECADHOME=$1
	LOCALPROD=$2

	if [ -z "$TEST_EXEC_FLAG" ]; then
		get_interp_env
	fi

	set_TME_ENV

	if [ -z "$TECADHOME" ]; then
		cat << EOF

		For installation in a non-TME environment, the TECADHOME environment
		variable must be set to the installation location of the adapter.
		This script will look for the adapter executables in \$TECADHOME/bin
		and the adapter configuration files in \$TECADHOME/etc.
EOF
		exit 10
	fi

	#-------------------------------------------------------------------
	# TECADHOME cannot be in the /etc/Tivoli/tecad tree, or the link
	# below will self-destruct.  It won't allow us to have the top
	# of the adapter tree at /etc/Tivoli/tecad.
	#-------------------------------------------------------------------
	if [ $INTERP != "w32-ix86" ]; then
		 case "$TECADHOME" in
			  "/etc/Tivoli/tecad/*")
					print_err "\$TECADHOME is in a subdirectory of /etc/Tivoli/tecad."
					print_err "Please move your adapter files to another directory."
					exit 10
					;;
		 esac

		set +e

		[ ! -d /etc/Tivoli ] && mkdir -p /etc/Tivoli
		$RM /etc/Tivoli/tecad
		[ -r /etc/Tivoli/tecad -o -d /etc/Tivoli/tecad ] && mv /etc/Tivoli/tecad /etc/Tivoli/tecad.$$
		ln -s $TECADHOME /etc/Tivoli/tecad

		set -e
	fi

	#-------------------------------------------------------------------
	# Configure the installation TECADHOME in the removal script
	#-------------------------------------------------------------------
	removeScript=$TECADHOME/bin/tecad-remove-${LOCALPROD}.sh

	if [ -f $removeScript ]; then
		cp  $CPOPTS $removeScript $removeScript.orig

		sed "s,^TECADHOME=\${TECADHOME:-},TECADHOME=\${TECADHOME:-$TECADHOME}," $removeScript.orig \
			| sed "s,^RUNDIR=\${RUNDIR:-},RUNDIR=\${RUNDIR:-$RUNDIR}," \
			> $removeScript

		if [ $? -eq 0 ]; then
			$RM $removeScript.orig
		fi
	fi
}

 #------------------------------------------------------------------
 # Set up TEC adapter configuration
 #------------------------------------------------------------------
configure_tecad()
{
	TECADHOME=$1
	PROD=$2

	if [ -z "$TEST_EXEC_FLAG" ]; then
		get_interp_env
	fi

	set_TME_ENV

	if [ -z "$TECADHOME" ]; then
		cat << EOF

		For installation in a non-TME environment, the TECADHOME environment
		variable must be set to the installation location of the adapter.
		This script will look for the adapter executables in \$TECADHOME/bin
		and the adapter configuration files in \$TECADHOME/etc.
EOF
		exit 10
	fi

	#-------------------------------------------------------------------
	# TECADHOME cannot be in the /etc/Tivoli/tecad tree, or the link
	# below will self-destruct.  It won't allow us to have the top
	# of the adapter tree at /etc/Tivoli/tecad.
	#-------------------------------------------------------------------
	if [ $INTERP != "w32-ix86" ]; then
		 case "$TECADHOME" in
			  "/etc/Tivoli/tecad/*")
					print_err "\$TECADHOME is in a subdirectory of /etc/Tivoli/tecad."
					print_err "Please move your adapter files to another directory."
					exit 10
					;;
		 esac

		set +e

		[ ! -d /etc/Tivoli ] && mkdir -p /etc/Tivoli
		$RM /etc/Tivoli/tecad
		[ -r /etc/Tivoli/tecad -o -d /etc/Tivoli/tecad ] && mv /etc/Tivoli/tecad /etc/Tivoli/tecad.$$
		ln -s $TECADHOME /etc/Tivoli/tecad

		set -e
	fi

	#-------------------------------------------------------------------
	# Edit the configuration file for the user if we are in a TME environment.
	# The absence of some files on an LCF endpoint can't be considered an
	# error because this script may be setting things up before the rest
	# of the files have been distributed.
	#-------------------------------------------------------------------
	if [ "$LCF_ENV" != "TRUE" ]; then
		if [ ! -x $TECADHOME/bin/${PROD}${EXE} ]; then
			 print_err ""
			 print_err "--------- cause of failure ---------" >&2
			 print_err "-- The adapter executable file ${PROD}$EXE is not in \$TECADHOME/bin."
			 print_err "    ($TECADHOME/bin/${PROD}$EXE)"
			 exit 10
		fi
	fi

	#-------------------------------------------------------------------
	# Configure the installation TECADHOME in the init.* script
	#-------------------------------------------------------------------
	initScript=$TECADHOME/bin/init.${PROD}

	if [ -f $initScript ]; then
		cp  $CPOPTS $initScript $initScript.orig

		sed "s,INSTALL_TECADHOME_PATH,$TECADHOME," $initScript.orig \
			| sed "s,^LCF_WORK_DIR=.*,LCF_WORK_DIR=$LCF_WORK_DIR," \
			| sed "s,^TIV_ENV=.*,TIV_ENV=$TIV_ENV," \
			| sed "s,^LCF_LIB_DIR=.*,LCF_LIB_DIR=$LCF_WORK_DIR/../../lib/$INTERP,"\
			> $initScript

		if [ $? -eq 0 ]; then
			$RM $initScript.orig
		fi
	fi

	confFileErrors=FALSE

	if [ "$TME_ENV" != "TRUE" -a "$LCF_ENV" != "TRUE" ]; then
		confFile=$TECADHOME/etc/${PROD}.conf

		MSG1="-- The adapter configuration file, $confFile,\n"
		MSG2="--   must be edited to set the ServerLocation for your environment."
		EDIT_CONF_MSG="${MSG1}${MSG2}"

		print_out ""
		print_out "Enter the hostname where your TEC Server is running:"
		read HostName

		if [ -z "$HostName" ]; then
			print_err "EDIT_CONF_MSG"
			print_err "  It should be set to the hostname where the TEC Server is running."
			confFileErrors=TRUE
		else
			cp $CPOPTS $confFile $confFile.orig
			sed "s,localhost,$HostName," $confFile.orig > $confFile

			if [ $? -ne 0 ]; then
				print_err ""
				print_err "--------- cause of failure ---------"
				print_err "-- Configuration file initialization failed"
				print_err "EDIT_CONF_MSG"
				print_err "  It should be set to the hostname where the TEC Server is running."
				confFileErrors=TRUE
			else
				$RM $confFile.orig
			fi
		fi
	fi
}

remove_rc_files()
{
	TME_ENV=$1
	AS=$2
	TECAD_START=$3
	PROD=$4
	INTERP=$5

	if [ "$TME_ENV" = "TRUE" -o $AS -eq 0 ]; then
		set_rc_filenames

		if [ -n "$CRCF" ]; then
			case "$INTERP" in
				hpux9|sunos4|aix3-r2|aix4-r1)
					if grep -s "$TECAD_START[-sd \t]* start[ \t]*&" $CRCF >/dev/null 2>&1; then
						cp -p $CRCF ${CRCF}-pre-${PROD}
						SRCH_STR=`echo $TECAD_START | sed -e 's,/,\\\/,g'`

						#
						# Edit the rc file.
						# First remove the "if [ .. ]; then" to the "fi" lines.
						# Save these changes in case the next command fails.
						# Then remove the comments before the "if - fi" block.
						#
						ed $CRCF <<EOF
/if .*$SRCH_STR/;/^[\t ]*fi[\t ]*\$/d
w
?^[\t ]*[^\t ##]?+1,?^[\t ]*#[\t ]*\$?d
w
q
EOF
					fi
					;;

				w32-ix86)
					;;

				hpux10|solaris2|*)
					$RM $CRCF
					[ -n "$MRCD" -a -f $MRCD/$PROD ] && $RM $MRCD/$PROD
					;;
			esac
		fi
	fi
}

 #------------------------------------------------------------------
 # Configure the adapter for automatic starting by the OS at boot time
 # This is very OS dependent
 #------------------------------------------------------------------
config_non_tme_autostart()
{
	TME_ENV=$1
	AS=$2
	TECAD_START=$3
	PROD=$4
	INTERP=$5

	APPNAME=${APPNAME:-$TECAD_START}

	if [ "$TME_ENV" != "TRUE" -a $AS -eq 1 ]; then
	  set_rc_filenames

	  case "$INTERP" in
			hpux9)
				if grep -s "^[	 ]*$TECAD_START start" ${CRCF} >/dev/null 2>&1; then
					print_err "${CRCF} is already configured to autostart this adapter"
				else
					if grep -s '^localrc()$' ${CRCF} >/dev/null 2>&1; then
						cp -p ${CRCF} ${CRCF}-pre-${PROD}

						#-----------------------------------
						# Add to localrc function in ${CRCF}
						#-----------------------------------
						ed ${CRCF} <<EOF
/^localrc()\$/
/^}\$/
i
 #
 # Start the $APPNAME
 #
if [ -f $TECAD_START ]; then
	$TECAD_START start &
fi
.
w
q
EOF
					else
						print_err "Addition for $APPNAME autostart failed:"
						print_err "    Error: can't find localrc function in ${CRCF}."
					fi
				fi
				;;

			sunos4|aix3-r2|aix4-r1)
				if grep -s "^[	 ]*$TECAD_START start" ${CRCF} >/dev/null 2>&1; then
					print_err "${CRCF} is already configured to autostart this adapter"
				else
					#-----------------------------------
					# Add to ${CRCF}
					#-----------------------------------
					cp ${CRCF} ${CRCF}-pre-${PROD}
					cat >> $CRCF <<EOF

 #
 # Start the $APPNAME
 #

if [ -f $TECAD_START ]; then
    $TECAD_START start &
    echo "$APPNAME started."
fi
EOF
				fi
				;;

			w32-ix86)
				;;

			hpux10|solaris2|*)
				#
				# If the directory exists for the master rc file, copy the startup
				# script there unless they are already identical.
				# Otherwise, just use the installed startup script.
				#
				if [ -d $MRCD ]; then
					MRCF="$MRCD/$PROD"
				else
					MRCF="${TECAD_START}.rc"
				fi

				[ -f $MRCF ] && $RM $MRCF

				#-----------------------------------
				# Add to ${CRCF}
				#-----------------------------------
				cat > $MRCF <<EOF
trap '' 1

PATH=/sbin:/usr/sbin:/usr/bin:/bin:\$PATH
export PATH

if [ -f $TECAD_START ]; then
	case "\$1" in
		'start') $TECAD_START \$1 & ;;
		*)       $TECAD_START \$1 ;;
	esac
fi
EOF
				chmod 755 $MRCF

				#
				# Create the links to the master rc file
				#
				for rcf in $CRCF; do
					[ -f $rcf ] && $RM $rcf
					ln -s $MRCF $rcf
				done
				;;
		esac    # interp case
	fi          # autostart stuff
}









 #-----------------------------------------------------------------------------
 # Search for existence of rules or class and import if not found
 #-----------------------------------------------------------------------------
import_files()
{
	IMPORT_LIST=$1
	LIST_METHOD=$2
	IMPORT_METHOD=$3

	if [ -n "$IMPORT_LIST" ]; then
		SEARCH_LIST=`idlcall -T top $TEC $LIST_METHOD '"Default"'`

		for IMPORT_FILE in $IMPORT_LIST; do
			found=FALSE

			for SRCH_FILE in $SEARCH_LIST; do
				if [ $SRCH_FILE = \"$IMPORT_FILE\" ]; then
					found=TRUE
				fi
			done

			if [ $found = "FALSE" ]; then
				set +e
				idlcall -T top $TEC $IMPORT_METHOD \"Default\" \"$mgdnode:$TECADHOME/etc/$IMPORT_FILE\" 0 \"\" "TRUE"
				set -e
			fi
		done
	fi
}

 #---------------------------------------------------------------------
 # Add the end point boot method
 #---------------------------------------------------------------------
add_boot_method()
{
	BOOT_METHOD=$1
	BOOT_METHOD_NAME=$2

	#-------------------------------------------------------------------
	#
	# Get the NameRegistry, InterfaceRepository and Library object IDs
	# If the appropriate env variables are already set, then we
	# don't need to get them again.  Additionally, if we need to get
	# the InterfaceRepository oid, go ahead and put it into replace mode.
	#
	#-------------------------------------------------------------------
	TNR=${TNR:-`wlookup NameRegistry`}
	CLO=${CLO:-`wlookup Library`}
	IR=`wlookup InterfaceRepository`
	idlattr -s -t $IR replace_mode boolean TRUE

	#-------------------------------------------------------------------
	# Update Interface Repository information
	#-------------------------------------------------------------------
	irpopulate $EXECDIR/$INTERP/TME/TEC/tec_ep_ir.tar

	#-------------------------------------------------------------------
	# Create new class:  imp_TEC_Endpoint::AdapterBoot
	#-------------------------------------------------------------------
	set +e
	imp_TEC_Endpoint_AdapterBoot_CO=`idlcall $CLO TMF_SysAdmin::Library::lookup_impl '\"imp_TEC_Endpoint::AdapterBoot\"'`

	if [ $? -ne 0 ]; then
		 set -e
		 imp_TEC_Endpoint_AdapterBoot_CO=`objcall $CLO create_class_cli -c  -i TEC_Endpoint::AdapterBoot     imp_TEC_Endpoint::AdapterBoot`
	fi
	set -e

	imp_TEC_Endpoint_AdapterBoot_BO=`idlcall $imp_TEC_Endpoint_AdapterBoot_CO TMF_Root::MetaBase::get_behavior`

	mextract $EXECDIR/$INTERP/TME/TEC/tec_ep_ist.tar << EOF
		imp_TEC_Endpoint::AdapterBoot $imp_TEC_Endpoint_AdapterBoot_BO
EOF

	MNCO=`wlookup -r Classes ManagedNode`
	winstendpt "$imp_TEC_Endpoint_AdapterBoot_CO" "$MNCO" || :;

        if [ -z "$ThisHost" ]; then
		ThisHostOid=`objcall 0.0.0 getattr HostLocation`
		ThisHost=`idlcall -v $ThisHostOid SysAdmin::PolicyDrivenBase::_get_label`
		ThisHost=`echo $ThisHost | awk -F'"' '{print $2}'`
	fi

	mnoid=`wlookup -r ManagedNode "$ThisHost"`
	objcall "$OSERV" boot_method add $BOOT_METHOD "$mnoid" $BOOT_METHOD_NAME || :;

}

 #---------------------------------------------------------------------
 # Remove the end point boot method
 #---------------------------------------------------------------------
rm_boot_method()
{
	BOOT_METHOD=$1
	BOOT_METHOD_NAME=$2

	TNR=${TNR:-`wlookup NameRegistry`}
	CLO=${CLO:-`wlookup Library`}

	#-------------------------------------------------------------------
	# Remove the boot method for this adapter
	#-------------------------------------------------------------------
	objcall $OSERV boot_method delete $BOOT_METHOD

	#-------------------------------------------------------------------
	# Not sure if there's anything else to clean up.
	# We don't want to just remove the class definition because there
	# probably other installed adapters that need it.
	#-------------------------------------------------------------------
}



 #---------------------------------------------------------------------
 # Construct a list of the installed adapters.
 # TECADHOME should already be defined.
 #---------------------------------------------------------------------
installed_adapter_list()
{
	_ADAPT_LIST=""

	if [ "$TME_ENV" = "TRUE" ]; then
		for AD_PROD in HPOV NV6K SNM SNMP LOGFILE NT SEM; do
			wlookup -r ProductInfo $AD_PROD >/dev/null 2>&1 \
				&& _ADAPT_LIST="$_ADAPT_LIST $AD_PROD"
		done
	elif [ -n "$TECADHOME" ]; then
		cd $TECADHOME/bin

		[ -f tecad_snmp ] && _ADAPT_LIST="$_ADAPT_LIST SNMP"
		[ -f tecad_snm ] && _ADAPT_LIST="$_ADAPT_LIST SNM"
		[ -f tecad_nv6k ] && _ADAPT_LIST="$_ADAPT_LIST NV6K"
		[ -f tecad_hpov ] && _ADAPT_LIST="$_ADAPT_LIST HPOV"
		[ -f tecad_logfile ] && _ADAPT_LIST="$_ADAPT_LIST LOGFILE"
		[ -f tecad_nt ] && _ADAPT_LIST="$_ADAPT_LIST NT"
	fi

	echo $_ADAPT_LIST
}

PATH=$PATH:/usr/ucb
SAVE_CFG_FILES=TRUE

APPNAME="TME 10 Enterprise Console Logfile Adapter"
PROD=tecad_logfile

 #------------------------------------------------------------------------------
 # After script must edit the script to correctly set the
 # following two environment variables. This will allow things
 # like installed_adapter_list() to work correctly without requiring
 # the user to set any environment variables prior to running the script
 # (when the script is run at the command line).
 #------------------------------------------------------------------------------
TECADHOME=${TECADHOME:-}
RUNDIR=${RUNDIR:-}

if [ -z "$TECADHOME" ]; then
	# we are running from the command line, non-tme, and the user
	# has not set TECADHOME as needed; inform user and exit.
	print_out "The TECADHOME environment variable must be set to the installation"
	print_out "directory of the adapter.  This directory should contain the 'bin'"
	print_out "and 'etc' sub-directories containing TEC adapter files."
	exit 1
fi

 ## Get TME_ENV value
get_tme_env

 ## Get INTERP value
get_interp_env

 #------------------------------------------------------------------------------
 # Unset autostart value so remove_rc_files() will work
 #------------------------------------------------------------------------------
AS=0
export AS

 #------------------------------------------------------------------------------
 # set TECAD_START value so remove_rc_files() will work
 #------------------------------------------------------------------------------
TECAD_START=bin/init.${PROD}

 #------------------------------------------------------------------------------
 # remove entries from the rc files
 #------------------------------------------------------------------------------
remove_rc_files "$TME_ENV" "$AS" "$TECAD_START" "$PROD" "$INTERP"

 #-------------------------------------------------------------------
 # Remove the endpoint boot method
 #-------------------------------------------------------------------
if [ "$TME_ENV" = "TRUE" ]; then
	# This section of the code may not be needed, as we won't be supporting
	# a managed node version of the logfile adapter (only non-tme and LCF).
	rm_boot_method TEC_Endpoint_logfile logfile
fi

LOGFILE_BIN=$TECADHOME/bin

 #------------------------------------------------------------------------------
 # Stop the adapter if it is running
 #------------------------------------------------------------------------------
PATH=$PATH:$LOGFILE_BIN
$LOGFILE_BIN/init.${PROD} stop &

 #------------------------------------------------------------------------------
 # wait for the adapter to stop before proceeding (so that when we attempt
 # to remove the executable, it won't be running...)
 #------------------------------------------------------------------------------
wait $!

 #------------------------------------------------------------------------------
 # Remove Product and Patch information from Tivoli
 #------------------------------------------------------------------------------
if [ "$TME_ENV" = "TRUE" ]; then
	# This section of the code may not be needed, as we won't be supporting
	# a managed node version of the logfile adapter (only non-tme and LCF).
	remove_ProductInfo LOGFILE
fi


 #------------------------------------------------------------------------------
 # Remove files
 #------------------------------------------------------------------------------
cd $TECADHOME


if [ "$TME_ENV" = "TRUE" -o "$LCF_ENV" = "TRUE" ]; then
		$RM etc/${PROD}.cds > /dev/null 2>&1
		$RM etc/${PROD}.conf  > /dev/null 2>&1
		$RM etc/${PROD}.err > /dev/null 2>&1
		$RM etc/${PROD}.fmt > /dev/null 2>&1
		$RM bin/$PROD > /dev/null 2>&1
		$RM bin/init.${PROD} > /dev/null 2>&1
		$RM bin/update_conf > /dev/null 2>&1
		$RM bin/tecad-remove-logfile.sh > /dev/null 2>&1
else
	# non-tme version
		$RM etc/${PROD}.cds > /dev/null 2>&1
		$RM etc/${PROD}.conf  > /dev/null 2>&1
		$RM etc/${PROD}.err > /dev/null 2>&1
		$RM etc/${PROD}.fmt > /dev/null 2>&1
		$RM etc/${PROD}.baroc > /dev/null 2>&1
		$RM etc/log_default.rls > /dev/null 2>&1
		$RM bin/$PROD > /dev/null 2>&1
		$RM bin/init.${PROD} > /dev/null 2>&1
		$RM bin/update_conf > /dev/null 2>&1
		$RM bin/logfile_gencds > /dev/null 2>&1
		$RM bin/${PROD}.cfg > /dev/null 2>&1
		$RM bin/tecad-remove-logfile.sh > /dev/null 2>&1
fi

 #------------------------------------------------------------------------------
 # Get the list of installed adapters (note that by being called AFTER doing
 # remove_ProductInfo and removing bin/tecad_logfile, LOGFILE will NOT be in the list)
 #------------------------------------------------------------------------------
ADAPT_LIST=`installed_adapter_list`

 #------------------------------------------------------------------------------
 # Don't remove (w)postemsg if any other adapters exist.
 #------------------------------------------------------------------------------
if [ -z "$ADAPT_LIST" ]; then
	if [ "$TME_ENV" = "TRUE" ]; then
		# This section of the code may not be needed, as we won't be supporting
		# a managed node version of the logfile adapter (only non-tme and LCF).
		cd $BINDIR

		$RM TME/TEC/tec_ep_ir.tar
		$RM TME/TEC/tec_ep_ist.tar

		wlookup -r ProductInfo TEC_SERVER || wlookup -r ProductInfo TEC_CONSOLE \
			|| $RM bin/wpostemsg && $RM bin/postemsg
	elif [ "$LCF_ENV" = "TRUE" ]; then
		$RM $TECADHOME/../../../bin/postemsg
		$RM $TECADHOME/../../../bin/wpostemsg
	else
		# non-tme version
		$RM $TECADHOME/bin/postemsg
	fi

	cd $TECADHOME
	rmdir $TECADHOME/bin > /dev/null 2>&1
	rmdir $TECADHOME/etc > /dev/null 2>&1
	# rmdir $TECADHOME > /dev/null 2>&1
fi

